@@ -2,9 +2,7 @@
  * GChemPaint GOffice component
  * gofficeapp.h
  *
- * Copyright (C) 2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2006 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -26,6 +24,9 @@
 #define GCP_GOFFICE_APP_H
 
 #include <lib/application.h>
+#include <map>
+
+using namespace std;
 
 class gcpGOfficeApplication: public gcpApplication
 {
@@ -38,9 +39,15 @@ public:
 	virtual void ToggleMenu(const string& menuname, bool active);
 
 	gcpDocument *ImportDocument (const string& mime_type, const char* data, int length);
+	bool EditDocument (GOGChemPaintComponent *gogcp);
 
 protected:
-	virtual void AddDocument(gcpDocument* pDoc);
+	virtual void AddDocument (gcpDocument *pDoc);
+
+private:
+
+private:
+	map<gcpDocument *, gpointer> m_Windows;
 };
 
 #endif	// GCP_GOFFICE_APP_H
