@@ -4,7 +4,7 @@
  * GChemPaint library
  * document.cc 
  *
- * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2006 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -22,16 +22,8 @@
  * USA
  */
 
-#ifndef HAS_OPENBABEL_2
-#	include <mol.h>
-#	undef PACKAGE
-#	undef PACKAGE_BUGREPORT
-#	undef PACKAGE_NAME
-#	undef PACKAGE_STRING
-#	undef PACKAGE_TARNAME
-#	undef PACKAGE_VERSION
-#	undef VERSION
-#endif
+#undef G_DISABLE_DEPRECATED
+
 #include "gchempaint-config.h"
 #include "application.h"
 #include "view.h"
@@ -41,18 +33,14 @@
 #include "reaction.h"
 #include "mesomery.h"
 #include "text.h"
+#include <locale.h>
 #include <unistd.h>
 #include <libgen.h>
 #include <gtk/gtk.h>
 #include <libgnomevfs/gnome-vfs-file-info.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
-#include <clocale>
-#ifdef HAS_OPENBABEL_2
-#	include <openbabel/mol.h>
-#	include <openbabel/obconversion.h>
-#else
-#	include <sstream>
-#endif
+#include <openbabel/mol.h>
+#include <openbabel/obconversion.h>
 
 using namespace OpenBabel;
 using namespace std;
@@ -60,34 +48,39 @@ using namespace std;
 SignalId OnChangedSignal;
 SignalId OnDeleteSignal;
 
-gcpDocument::gcpDocument(gcpApplication *App, bool StandAlone): Document()
+gcpDocument::gcpDocument(gcpApplication *App, bool StandAlone, gcpWindow *window): Document()
 {
 	m_pApp = App;
 	m_pView = NULL;
+	m_Window = window;
 	m_filename = NULL;
 	m_label = NULL;
 	m_title = NULL;
 	m_pView = new gcpView(this, !StandAlone);
 	m_bDirty = m_bIsLoading = m_bUndoRedo = false;
 	m_bWriteable = true;
-#ifdef HAS_OPENBABEL_2
 	m_FileType = gcp_ft_Normal;
-#else
-	m_FileType = UNDEFINED;
-#endif
 	m_DocPropDlg = NULL;
 	g_date_set_time(&CreationDate, time(NULL));
 	g_date_clear(&RevisionDate, 1);
-	const char* chn = getenv("USERNAME");
-	if (chn) m_author = g_strdup(chn);
-	else m_author = NULL;
-	chn = getenv("E_MAIL");
-	if (chn) m_mail = g_strdup(chn);
-	else m_mail = NULL;
+	const char* chn = getenv ("REAL_NAME");
+	if (!chn)
+		chn = getenv ("USERNAME");
+	if (chn)
+		m_author = g_strdup(chn);
+	else
+		m_author = NULL;
+	chn = getenv ("E_MAIL");
+	if (!chn)
+		chn = getenv ("EMAIL_ADDRESS");
+	if (chn)
+		m_mail = g_strdup (chn);
+	else
+		m_mail = NULL;
 	m_comment = NULL;
 	m_pCurOp = NULL;
 	m_bReadOnly = false;
-	SetActive();
+	SetActive ();
 }
 
 gcpDocument::~gcpDocument ()
@@ -183,12 +176,12 @@ bool gcpDocument::ImportOB(OBMol& Mol)
 	OBBond *bond;
 	vector<OBEdgeBase*>::iterator j;
 	bond = Mol.BeginBond(j);
-	double l = (bond)? floor(DefaultBondLength / bond->GetLength()): 1.;
+	double l = floor(DefaultBondLength / bond->GetLength());
 	if (l == 0) l = 1;
 	m_title = g_strdup(Mol.GetTitle());
 	OBAtom *atom;
 	gcpAtom* pAtom;
-	double xmin = 0., xmax = 0., ymin = 0., ymax = 0., x, y;
+	double xmin = DBL_MAX, xmax = 0., ymin = DBL_MAX, ymax = 0., x, y;
 	bool valid = false;
 	vector<OBNodeBase*>::iterator i;
 	for (atom = Mol.BeginAtom(i); atom; atom = Mol.NextAtom(i))
@@ -267,11 +260,7 @@ void gcpDocument::BuildAtomTable(map<string, unsigned>& AtomTable, Object* obj,
 
 void gcpDocument::ExportOB()
 {
-#ifdef HAS_OPENBABEL_2
 	OBMol Mol;
-#else
-	OBMol Mol(UNDEFINED, (io_type) m_FileType);
-#endif
 	map<string, unsigned>::iterator i;
 	map<string, unsigned> AtomTable;
 	list<gcpBond*> BondList;
@@ -284,9 +273,7 @@ void gcpDocument::ExportOB()
 	BuildAtomTable(AtomTable, this, index);
 	Mol.ReserveAtoms(AtomTable.size());
 	Mol.SetTitle((char*)GetTitle());
-#ifdef HAS_OPENBABEL_2
 	Mol.SetDimension (2);
-#endif
 	for (i = AtomTable.begin(); i != AtomTable.end(); i++)
 	{
 		pgAtom = (gcpAtom*)GetDescendant((*i).first.data());
@@ -319,8 +306,7 @@ void gcpDocument::ExportOB()
 		Mol.AddBond(start, end, order, flag);
 	}
 	Mol.EndModify();
-	try
-	{
+	try {
 		ostringstream ofs;
 		GnomeVFSHandle *handle = NULL;
 		GnomeVFSFileSize n;
@@ -329,15 +315,10 @@ void gcpDocument::ExportOB()
 			throw (int) res;
 		old_num_locale = g_strdup(setlocale(LC_NUMERIC, NULL));
 		setlocale(LC_NUMERIC, "C");
-#ifdef HAS_OPENBABEL_2
 		OBConversion Conv;
 		OBFormat* pOutFormat = Conv.FormatFromExt (m_filename);
 		Conv.SetInAndOutFormats (pOutFormat, pOutFormat);
 		Conv.Write (&Mol, &ofs);
-#else
-		OBFileFormat fileFormat;
-		fileFormat.WriteMolecule(ofs, Mol, "2D");
-#endif
 		setlocale(LC_NUMERIC, old_num_locale);
 		g_free(old_num_locale);
 		if ((res = gnome_vfs_write (handle, ofs.str ().c_str (), (GnomeVFSFileSize) ofs.str ().size (), &n)) != GNOME_VFS_OK)
@@ -345,9 +326,8 @@ void gcpDocument::ExportOB()
 		gnome_vfs_close (handle);
 		SetReadOnly (false);
 	}
-	catch (int n)
-	{
-		printf("error #%d\n",n);
+	catch (int n) {
+		fprintf(stderr, "gnome-vfs error #%d\n",n);
 	}
 }
 
@@ -374,7 +354,6 @@ void gcpDocument::AddAtom(gcpAtom* pAtom)
 	m_pView->AddObject(pAtom);
 	if (m_bIsLoading)
 		return;
-//	AddObject(pAtom);
 	gcpMolecule* mol = new gcpMolecule();
 	i = 1;
 	id[0] = 'm';
@@ -478,20 +457,68 @@ void gcpDocument::AddBond(gcpBond* pBond)
 	m_bDirty = true;
 }
 
+static int cb_xml_to_vfs (GnomeVFSHandle *handle, const char* buf, int nb)
+{
+	GnomeVFSFileSize ndone;
+	return (int) gnome_vfs_write (handle, buf, nb, &ndone);
+}
+
 void gcpDocument::Save()
 {
-	if (!m_filename || !m_bWriteable || m_bReadOnly) return;
-#ifdef HAS_OPENBABEL_2
-	if (m_FileType != gcp_ft_Normal)
-#else
-	if (m_FileType != UNDEFINED)
-#endif
-	{
-		ExportOB();
+	if (!m_filename || !m_bWriteable || m_bReadOnly)
+		return;
+	xmlDocPtr xml = NULL;
+	char *old_num_locale, *old_time_locale;
+	
+	old_num_locale = g_strdup (setlocale (LC_NUMERIC, NULL));
+	setlocale(LC_NUMERIC, "C");
+	old_time_locale = g_strdup (setlocale (LC_TIME, NULL));
+	setlocale (LC_TIME, "C");
+
+	try {
+		if (m_FileType != gcp_ft_Normal)
+			ExportOB ();
+		else {
+			xml = BuildXMLTree();
+			xmlIndentTreeOutput = true;
+			xmlKeepBlanksDefault(0);
+		
+			GnomeVFSFileInfo *info = gnome_vfs_file_info_new ();
+			gnome_vfs_get_file_info (m_filename, info, GNOME_VFS_FILE_INFO_DEFAULT);
+		
+			if (GNOME_VFS_FILE_INFO_LOCAL (info)) {
+				gnome_vfs_file_info_unref (info);
+				if (xmlSaveFormatFile (m_filename, xml, true) < 0) /*Error(SAVE)*/;
+			} else {
+				gnome_vfs_file_info_unref (info);
+				xmlOutputBufferPtr buf = xmlAllocOutputBuffer (NULL);
+				GnomeVFSHandle *handle;
+				GnomeVFSResult result = gnome_vfs_open (&handle, m_filename, GNOME_VFS_OPEN_WRITE);
+				if (result == GNOME_VFS_ERROR_NOT_FOUND)
+					result = gnome_vfs_create (&handle, m_filename, GNOME_VFS_OPEN_WRITE, true, 0666);
+				if (result != GNOME_VFS_OK)
+					throw 1;
+				buf->context = handle;
+				buf->closecallback = (xmlOutputCloseCallback) gnome_vfs_close;
+				buf->writecallback = (xmlOutputWriteCallback) cb_xml_to_vfs;
+				int n = xmlSaveFormatFileTo (buf, xml, NULL, true);
+				if (n < 0)
+					throw 1;
+				SetReadOnly (false);
+			}
+		}
+		m_bDirty = false;
 	}
-	else
-		BuildXMLTree();
-	m_bDirty = false;
+	catch (int num) {
+		if (xml)
+			xmlFreeDoc (xml);
+		xml = NULL;
+//		Error (SAVE);
+	}
+	setlocale (LC_NUMERIC, old_num_locale);
+	g_free (old_num_locale);
+	setlocale (LC_TIME, old_time_locale);
+	g_free (old_time_locale);
 }
 
 bool gcpDocument::Load (xmlNodePtr root)
@@ -514,11 +541,7 @@ bool gcpDocument::Load (xmlNodePtr root)
 	}
 	g_date_clear (&CreationDate, 1);
 	g_date_clear (&RevisionDate, 1);
-#ifdef HAS_OPENBABEL_2
 	m_FileType = gcp_ft_Normal;
-#else
-	m_FileType = UNDEFINED;
-#endif
 	xmlNodePtr node, child;
 	char* tmp;
 	Object* pObject;
@@ -540,7 +563,7 @@ bool gcpDocument::Load (xmlNodePtr root)
 		xmlFree (tmp);
 	}
 
-	node = GetNodeByName (root, const_cast<char*> ("title"));
+	node = GetNodeByName (root, "title");
 	if (node)
 	{
 		tmp = (char*) xmlNodeGetContent (node);
@@ -549,7 +572,7 @@ bool gcpDocument::Load (xmlNodePtr root)
 			xmlFree (tmp);
 		}
 	}
-	node = GetNodeByName (root, const_cast<char*> ("author"));
+	node = GetNodeByName (root, "author");
 	if (node)
 	{
 		tmp = (char*) xmlGetProp (node, (xmlChar*) "name");
@@ -563,7 +586,7 @@ bool gcpDocument::Load (xmlNodePtr root)
 			xmlFree (tmp);
 		}
 	}
-	node = GetNodeByName (root, const_cast<char*> ("comment"));
+	node = GetNodeByName (root, "comment");
 	if (node)
 	{
 		tmp = (char*) xmlNodeGetContent (node);
@@ -599,113 +622,64 @@ void gcpDocument::ParseXMLTree (xmlDocPtr xml)
 	Load (xml->children);
 }
 
-static int cb_xml_to_vfs (GnomeVFSHandle *handle, const char* buf, int nb)
-{
-	GnomeVFSFileSize ndone;
-	return (int) gnome_vfs_write (handle, buf, nb, &ndone);
-}
-
 xmlDocPtr gcpDocument::BuildXMLTree()
 {
 	xmlDocPtr xml;
 	xmlNodePtr node;
 	xmlNsPtr ns;
-	char *old_num_locale, *old_time_locale;
 
 	xml = xmlNewDoc((xmlChar*)"1.0");
 //FIXME: do something if an error occurs 
-	if (xml == NULL) {/*Error(SAVE);*/ return NULL;}
+	if (xml == NULL)
+		throw (int) 0;
 	
-	old_num_locale = g_strdup(setlocale(LC_NUMERIC, NULL));
-	setlocale(LC_NUMERIC, "C");
-	old_time_locale = g_strdup(setlocale(LC_TIME, NULL));
-	setlocale(LC_TIME, "C");
-	
-	xml->children =  xmlNewDocNode(xml, NULL, (xmlChar*)"chemistry", NULL);
+	xml->children =  xmlNewDocNode (xml, NULL, (xmlChar*) "chemistry", NULL);
 	ns = xmlNewNs (xml->children, (xmlChar*) "http://www.nongnu.org/gchempaint", (xmlChar*) "gcp");
 	xmlSetNs (xml->children, ns);
-	if (!g_date_valid(&CreationDate))
-		g_date_set_time(&CreationDate, time(NULL));
-	g_date_set_time(&RevisionDate, time(NULL));
-	gchar tmp[64];
-	g_date_strftime(tmp, sizeof(tmp), "%m/%d/%Y", &CreationDate);
-	xmlNewProp(xml->children, (xmlChar*)"creation", (xmlChar*) tmp);
-	g_date_strftime(tmp, sizeof(tmp), "%m/%d/%Y", &RevisionDate);
-	xmlNewProp(xml->children, (xmlChar*)"revision", (xmlChar*) tmp);
-	try
-	{
-		node = xmlNewDocNode(xml, NULL, (xmlChar*)"generator", (xmlChar*)"GChemPaint "VERSION);
-		if (node) xmlAddChild(xml->children, node); else throw (int) 0;
+	if (!g_date_valid (&CreationDate))
+		g_date_set_time (&CreationDate, time (NULL));
+	g_date_set_time (&RevisionDate, time (NULL));
+	gchar buf[64];
+	g_date_strftime (buf, sizeof (buf), "%m/%d/%Y", &CreationDate);
+	xmlNewProp (xml->children, (xmlChar*) "creation", (xmlChar*) buf);
+	g_date_strftime (buf, sizeof (buf), "%m/%d/%Y", &RevisionDate);
+	xmlNewProp (xml->children, (xmlChar*) "revision", (xmlChar*) buf);
+	node = xmlNewDocNode(xml, NULL, (xmlChar*)"generator", (xmlChar*)"GChemPaint "VERSION);
+	if (node)
+		xmlAddChild (xml->children, node);
+	else
+		throw (int) 0;
 
-		if (m_title && *m_title)
-		{
-			node = xmlNewDocNode(xml, NULL, (xmlChar*)"title", (xmlChar*)m_title);
-			if (node) xmlAddChild(xml->children, node); else throw (int) 0;
-		}
-		if ((m_author && *m_author) || (m_mail && *m_mail))
-		{
-			node = xmlNewDocNode(xml, NULL, (xmlChar*)"author", NULL);
-			if (node)
-			{
-				if (m_author && *m_author) xmlNewProp(node, (xmlChar*)"name", (xmlChar*)m_author);
-				if (m_mail && *m_mail) xmlNewProp(node, (xmlChar*)"e-mail", (xmlChar*)m_mail);
-				xmlAddChild(xml->children, node);
-			}
-			else throw (int) 0;
-		}
-		if (m_comment && *m_comment)
-		{
-			node = xmlNewDocNode(xml, NULL, (xmlChar*)"comment", (xmlChar*)m_comment);
-			if (node) xmlAddChild(xml->children, node); else throw (int) 0;
-		}
-		
-		if (!SaveChildren(xml, xml->children)) throw 1;
-
-		xmlIndentTreeOutput = true;
-		xmlKeepBlanksDefault(0);
-
-		GnomeVFSFileInfo *info = gnome_vfs_file_info_new ();
-		gnome_vfs_get_file_info (m_filename, info, GNOME_VFS_FILE_INFO_DEFAULT);
-
-		if (GNOME_VFS_FILE_INFO_LOCAL (info)) {
-			gnome_vfs_file_info_unref (info);
-			if (xmlSaveFormatFile (m_filename, xml, true) < 0) /*Error(SAVE)*/;
-		} else {
-			gnome_vfs_file_info_unref (info);
-			xmlOutputBufferPtr buf = xmlAllocOutputBuffer (NULL);
-			GnomeVFSHandle *handle;
-			GnomeVFSResult result = gnome_vfs_open (&handle, m_filename, GNOME_VFS_OPEN_WRITE);
-			if (result == GNOME_VFS_ERROR_NOT_FOUND)
-				result = gnome_vfs_create (&handle, m_filename, GNOME_VFS_OPEN_WRITE, true, 0666);
-			if (result != GNOME_VFS_OK)
-				throw 1;
-			buf->context = handle;
-			buf->closecallback = (xmlOutputCloseCallback) gnome_vfs_close;
-			buf->writecallback = (xmlOutputWriteCallback) cb_xml_to_vfs;
-			int n = xmlSaveFormatFileTo (buf, xml, NULL, true);
-			if (n < 0)
-				throw 1;
-			SetReadOnly (false);
-		}
-//FIXME: the xml is freed and then we return it!!!
-		xmlFreeDoc(xml);
-		m_bDirty = false;
-
-		setlocale(LC_NUMERIC, old_num_locale);
-		g_free(old_num_locale);
-		setlocale(LC_TIME, old_time_locale);
-		g_free(old_time_locale);
+	if (m_title && *m_title) {
+		node = xmlNewDocNode (xml, NULL, (xmlChar*) "title", (xmlChar*) m_title);
+		if (node)
+			xmlAddChild (xml->children, node);
+		else
+			throw (int) 0;
 	}
-	catch (int num)
-	{
-		xmlFreeDoc(xml);
-		xml = NULL;
-		setlocale(LC_NUMERIC, old_num_locale);
-		g_free(old_num_locale);
-		setlocale(LC_TIME, old_time_locale);
-		g_free(old_time_locale);
-//		Error(SAVE);
+	if ((m_author && *m_author) || (m_mail && *m_mail)) {
+		node = xmlNewDocNode (xml, NULL, (xmlChar*) "author", NULL);
+		if (node) {
+			if (m_author && *m_author)
+				xmlNewProp (node, (xmlChar*) "name", (xmlChar*) m_author);
+			if (m_mail && *m_mail)
+				xmlNewProp (node, (xmlChar*) "e-mail", (xmlChar*) m_mail);
+			xmlAddChild (xml->children, node);
+		}
+		else
+			throw (int) 0;
 	}
+	if (m_comment && *m_comment) {
+		node = xmlNewDocNode (xml, NULL, (xmlChar*) "comment", (xmlChar*) m_comment);
+		if (node)
+			xmlAddChild (xml->children, node);
+		else
+			throw (int) 0;
+	}
+	
+	if (!SaveChildren (xml, xml->children))
+		throw 1;
+
 	return xml;
 }
 
@@ -1064,7 +1038,7 @@ void gcpDocument::LoadObjects(xmlNodePtr node)
 		child = child->next;
 	}
 	//Now, add bonds
-	child = GetNodeByName(node, const_cast<char*> ("bond"));
+	child = GetNodeByName(node, "bond");
 	while (child)
 	{
 		gcpBond* pBond = new gcpBond();
@@ -1072,7 +1046,7 @@ void gcpDocument::LoadObjects(xmlNodePtr node)
 		if (pBond->Load(child))
 			AddBond(pBond);
 		else delete pBond;
-		child = GetNextNodeByName(child->next, const_cast<char*> ("bond"));
+		child = GetNextNodeByName(child->next, "bond");
 	}
 }
 
