@@ -4,9 +4,7 @@
  * GChemPaint library
  * electron.cc
  *
- * Copyright (C) 2004-2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2005 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -355,3 +353,14 @@ bool gcpElectron::OnSignal (SignalId Signal, Object *Child)
 	pDoc->FinishOperation ();
 	return false;
 }
+
+void gcpElectron::Transform2D (Matrix2D& m, double x, double y)
+{
+	double a = m_Angle * M_PI / 180.;
+	double xc = cos (a), yc = - sin (a);
+	m.Transform (xc, yc);
+	a = atan2 (- yc, xc) * 180. / M_PI;
+	if (a < 0)
+		a += 360;
+	SetPosition (0, a, m_Dist);
+}
