@@ -4,7 +4,7 @@
  * GChemPaint library
  * reaction-step.cc 
  *
- * Copyright (C) 2004-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2005 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -37,13 +37,13 @@ TypeId ReactionStepType = NoType;
 
 gcpReactionStep::gcpReactionStep (): Object (ReactionStepType)
 {
-	SetId (const_cast<char*> ("rs1"));
+	SetId ("rs1");
 	m_bLoading = false;
 }
 
 gcpReactionStep::gcpReactionStep (gcpReaction *reaction, map<double, Object*>& Children, map<Object*, ArtDRect> Objects): Object (ReactionStepType)
 {
-	SetId (const_cast<char*> ("rs1"));
+	SetId ("rs1");
 	reaction->AddChild (this);
 	GetDocument ()->EmptyTranslationTable ();
 	gcpDocument *pDoc = (gcpDocument*) GetDocument ();
@@ -132,7 +132,7 @@ xmlNodePtr gcpReactionStep::Save (xmlDocPtr xml)
 	xmlNodePtr child;
 	while (obj) {
 		if ((*i).second->GetType () != ReactionOperatorType) {
-			if ((child = (*i).second->Save (xml))) xmlAddChild (node, child);
+			if (child = (*i).second->Save (xml)) xmlAddChild (node, child);
 			else return NULL;
 		}
 		obj = GetNextChild (i);
