@@ -4,9 +4,7 @@
  * GChemPaint library
  * text.cc 
  *
- * Copyright (C) 2002-2004
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2005 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -20,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -85,7 +83,6 @@ Derivation of a new widget from GnomeCanvasRichTextExt with an event for setting
 */
 static void gnome_canvas_rich_text_gcp_class_init(GnomeCanvasRichTextGCPClass *Class);
 static void gnome_canvas_rich_text_gcp_init(GnomeCanvasRichTextGCP *canvas);
-static GtkWidget *gnome_canvas_rich_text_gcp_new (void);
 
 static void gnome_canvas_rich_text_gcp_realize(GnomeCanvasItem *item);
 static gint gnome_canvas_rich_text_gcp_event(GnomeCanvasItem *item, GdkEvent *event);
@@ -140,11 +137,11 @@ static void gnome_canvas_rich_text_gcp_realize(GnomeCanvasItem *item)
 
 static gint gnome_canvas_rich_text_gcp_event(GnomeCanvasItem *item, GdkEvent *event)
 {
-	GnomeCanvasRichTextExt *text = GNOME_CANVAS_RICH_TEXT_EXT(item);
 	gcpText* pText = (gcpText*)g_object_get_data(G_OBJECT(item), "object");
 	if (pText)
 		if (!pText->OnEvent(event))
 			(* GNOME_CANVAS_ITEM_CLASS(parent_class)->event)(item, event);
+	return true;
 }
 
 gcpText::gcpText(): gcpTextObject(TextType)
@@ -229,7 +226,7 @@ bool gcpText::SaveNode(xmlDocPtr xml, xmlNodePtr node, GtkTextIter *iter, GtkTex
 	{
 		//find the longest included tag
 		TagList0 = TagList;
-		GtkTextTag *tag;
+		GtkTextTag *tag = NULL;
 		while (TagList0)
 		{
 			next = start;
@@ -475,7 +472,6 @@ bool gcpText::OnChanged (GtkTextBuffer *textbuffer)
 		return true;
 	}
 	while (bNotEnd) {
-		gtk_text_iter_backward_line (&iter);
 		gnome_canvas_rich_text_ext_get_iter_location (text, &iter, &rect);
 		if (left > rect.x)
 			left = rect.x;
@@ -659,12 +655,22 @@ void gcpText::SetSelected(GtkWidget* w, int state)
 	gcpWidgetData* pData = (gcpWidgetData*)g_object_get_data(G_OBJECT(w), "data");
 	GnomeCanvasGroup* group = pData->Items[this];
 	gchar* color;
-	switch (state)
-	{	
-		case SelStateUnselected: color = "white"; break;
-		case SelStateSelected: color = SelectColor; break;
-		case SelStateUpdating: color = AddColor; break;
-		case SelStateErasing: color = DeleteColor; break;
+	switch (state) {	
+	case SelStateUnselected:
+		color = "white";
+		break;
+	case SelStateSelected:
+		color = SelectColor;
+		break;
+	case SelStateUpdating:
+		color = AddColor;
+		break;
+	case SelStateErasing:
+		color = DeleteColor;
+		break;
+	default:
+		color = "white";
+		break;
 	}
 	g_object_set(G_OBJECT(g_object_get_data(G_OBJECT(group), "rect")), "fill_color", color, NULL);
 }
