@@ -4,9 +4,7 @@
  * GChemPaint library
  * view.cc
  *
- * Copyright (C) 2001-2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2005 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -820,12 +818,8 @@ void gcpView::OnSelectAll()
 	gcpTool* pActiveTool = pApp->GetTool("Select");
 	if (pActiveTool) pApp->ActivateTool("Select", true);
 	m_pData->SelectAll();
-	if (pActiveTool) {
+	if (pActiveTool)
 		pActiveTool->AddSelection(m_pData);
-		pApp->ActivateToolItem ("Merge", ((m_pData->SelectedObjects.size () == 2) &&
-			(m_pData->SelectedObjects.front()->GetType() == MoleculeType) &&
-			(m_pData->SelectedObjects.back()->GetType() == MoleculeType)));
-	}
 }
 
 void gcpView::ExportImage (const char* filename, const char* type)
