@@ -4,7 +4,7 @@
  * GChemPaint cycles plugin
  * cycletool.cc 
  *
- * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2005 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -28,13 +28,13 @@
 #include "lib/mendeleiev.h"
 #include "lib/document.h"
 #include "lib/application.h"
-#include <cmath>
+#include <math.h>
 #include <list>
 #include <vector>
 
 using namespace std;
 
-static char const *ToolNames [] = {
+static char* ToolNames [] = {
 	"Cycle3",
 	"Cycle4",
 	"Cycle5",
@@ -220,7 +220,7 @@ bool gcpCycleTool::OnClicked()
 						pBond = (gcpBond*)pAtom->GetFirstBond(j);
 						orientations.push_back(pBond->GetAngle2DRad(pAtom));
 						unsigned k;
-						while ((pBond = (gcpBond*)pAtom->GetNextBond(j)))
+						while (pBond = (gcpBond*)pAtom->GetNextBond(j))
 						{
 							k = 0;
 							a0 = pBond->GetAngle2DRad(pAtom);
@@ -738,7 +738,7 @@ bool gcpCycleTool::CheckIfAllowed()
 	return true;
 }
 
-class gcpCNToolDlg: public gcpDialog
+class gcpCNToolDlg: public Dialog
 {
 public:
 	gcpCNToolDlg(gcpApplication* App, unsigned char size = 9);
@@ -769,17 +769,35 @@ void gcpNCycleTool::SetSize(unsigned char size)
 	if ((m_size = size)) Init();
 }
 
-void gcpNCycleTool::SetOptions()
+static void on_size_changed (GtkSpinButton *button, gcpNCycleTool *tool)
 {
-	gcpCNToolDlg* dlg = (gcpCNToolDlg*) m_pApp->GetDialog("CycleN");
-	if (!dlg)
-	{
-		dlg = new gcpCNToolDlg (m_pApp, GetSize());
-	}
-	else gdk_window_raise (GTK_WIDGET(dlg->GetWindow())->window); 
+	tool->SetSize ((unsigned char) gtk_spin_button_get_value_as_int (button));
 }
 
-gcpCNToolDlg::gcpCNToolDlg(gcpApplication* App, unsigned char size): gcpDialog(App, GLADEDIR"/cyclentool.glade", "cyclentool")
+GtkWidget *gcpNCycleTool::GetPropertyPage ()
+{
+	GladeXML *xml = glade_xml_new (DATADIR"/gchempaint-unstable/ui/cyclentool.glade", "size-box", GETTEXT_PACKAGE);
+	GtkWidget *w = glade_xml_get_widget (xml, "size-box");
+	GtkWidget *vbox = gtk_vbox_new (false, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), w, false, false, 0);
+	gtk_widget_show (vbox);
+	w = glade_xml_get_widget (xml, "sizebtn");
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (w), m_size);
+	g_signal_connect (G_OBJECT (w), "value-changed", G_CALLBACK (on_size_changed), this);
+	return vbox;
+}
+
+void gcpNCycleTool::SetOptions ()
+{
+	gcpCNToolDlg* dlg = (gcpCNToolDlg*) m_pApp->GetDialog ("CycleN");
+	if (!dlg)
+	{
+		dlg = new gcpCNToolDlg (m_pApp, GetSize ());
+	}
+	else gdk_window_raise (GTK_WIDGET (dlg->GetWindow ())->window); 
+}
+
+gcpCNToolDlg::gcpCNToolDlg(gcpApplication* App, unsigned char size): Dialog(App, DATADIR"/gchempaint-unstable/ui/cyclentool.glade", "cyclentool")
 {
 	m_button = GTK_SPIN_BUTTON(glade_xml_get_widget(xml, "sizebtn"));
 	gtk_spin_button_set_value(m_button, size);
@@ -787,15 +805,16 @@ gcpCNToolDlg::gcpCNToolDlg(gcpApplication* App, unsigned char size): gcpDialog(A
 	gtk_widget_show(GTK_WIDGET(dialog));
 }
 
-gcpCNToolDlg::~gcpCNToolDlg()
+gcpCNToolDlg::~gcpCNToolDlg ()
 {
-	m_App->SetDialog("CycleN", NULL);
+	reinterpret_cast<gcpApplication*> (m_App)->SetDialog ("CycleN", NULL);
 }
 
-bool gcpCNToolDlg::Apply()
+bool gcpCNToolDlg::Apply ()
 {
-	gcpNCycleTool* tool = (gcpNCycleTool*)m_App->GetTool("CycleN");
+	gcpNCycleTool* tool = (gcpNCycleTool*)
+			reinterpret_cast<gcpApplication*> (m_App)->GetTool ("CycleN");
 	if (tool)
-		tool->SetSize((unsigned char)gtk_spin_button_get_value_as_int(m_button));
+		tool->SetSize ((unsigned char) gtk_spin_button_get_value_as_int (m_button));
 	return true;
 }
