@@ -4,9 +4,7 @@
  * GChemPaint
  * main.cc 
  *
- * Copyright (C) 2001-2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2006 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -38,18 +36,17 @@ extern "C" {
 #undef PACKAGE
 #define PACKAGE "gchempaint-unstable" 
 
-gboolean cb_print_version (const gchar *option_name, const gchar *value, gpointer data, GError **error)
+void cb_print_version (const gchar *option_name, const gchar *value, gpointer data, GError **error)
 {
 	char *version = g_strconcat (_("GChemPaint version: "), VERSION, NULL);
 	puts (version);
 	g_free (version);
 	exit (0);
-	return TRUE;
 }
 
 static GOptionEntry entries[] = 
 {
-  { "version", 'v', 0, G_OPTION_ARG_CALLBACK, (void*) cb_print_version, "prints GChemPaint version", NULL },
+  { "version", 'v', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, (void*) cb_print_version, "prints GChemPaint version", NULL },
    { NULL }
 };
 
@@ -70,6 +67,7 @@ int main(int argc, char *argv[])
 		context = g_option_context_new (_(" [file...]"));
 		g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
 		g_option_context_add_group (context, gtk_get_option_group (TRUE));
+		g_option_context_set_help_enabled (context, TRUE);
 		g_option_context_parse (context, &argc, &argv, &error);
 		if (error) {
 			puts (error->message);
